import os
from django.core.paginator import Paginator
from django.utils.translation import ugettext as _
from django.conf import settings

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool
from filer.models import Folder, File as FolderFile

from jmb.document.cms.models import DocumentSettings
from jmb.document.cms.utils import File, Directory

###################################
## CMS PLUGINS                    #
###################################

class DocumentPlugin(CMSPluginBase):
    model = DocumentSettings
    name = _("Document Plugin")



    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        message = ''
        try:
            folder = Folder.objects.get(name=instance.dirpath)
            folder_qs = folder.get_descendants()
            file_qs = FolderFile.objects.filter(
                         folder=folder
                      )
            folder_qs = folder_qs.order_by('name')
            file_qs = file_qs.order_by('name')

            folder_children = []
            folder_files = []


            for f in folder_qs:
                folder_children.append(f)
            for fi in file_qs:
                folder_files.append(fi)

            #folder_files.sort()
            items = folder_children + folder_files
            objects = items

        except Folder.DoesNotExist:
            message = "no folder name '"+instance.dirpath+"'"
            objects = []
            print message

        context.update({

                'instance': instance,
                'placeholder': placeholder,
                'objects': objects,
                'message':message,

                })
        return context


    # alternativa: legge da filesystem
#    def render(self, context, instance, placeholder):
#        self.render_template = instance.template_name
#        filelist = []
#        abs_path = settings.MEDIA_ROOT+instance.dirpath
#        url_path = settings.MEDIA_URL+instance.dirpath
#        directory = Directory(abs_path, url_path, instance.dirpath)
#
#
#
#        context.update({
#
#            'instance': instance,
#            'placeholder': placeholder,
#            'directory': directory,
#            'abs_path':abs_path,
#
#        })
#        return context



plugin_pool.register_plugin(DocumentPlugin)

